/**
 ******************************************************************************
 * @project  Serial LED Control
 * @author   Edward Ahn, Jim jun
 * @version  V1.0.1
 * @date     26-MAY-2016
 * @brief    Serial Communication
*******************************************************************************
**/

/* 아두이노 보드와 컴퓨터 사이에 시리얼 연결이 성립되면 처음 송수신되는 데이터는 잡음의 영
향으로 잘못된 데이터가 전달될 수 있다. 따라서 초기 연결 시에 서로 약속한 신호를 주고받
음으로써(handshaking) 연결이 되도록 수정하면 초기의 잡음 데이터에 의한 오동작을 방지할
수 있다. */

#include <SoftwareSerial.h>

SoftwareSerial mySerial(0, 1); // RX, TX

const int ledPin = 9; // LED PIN 설정
char buffer[100] = {0,}; // 버퍼 사이즈 100 byte 배열로 설정

void Establish_Connection() { // 함수 선언
  mySerial.println("Send me back \'OK Message\'"); // ‘OK’ 문자열 모듈로 보내도록 알림
  while(true){
    if(mySerial.available()){ // 수신 문자열이 있는 경우
    int readCount = mySerial.readBytes(buffer, 99); // 문자열 읽기 + 수신된 문자열 길이 check
    buffer[readCount] = '\0'; // 종료문자 추가
    // 수신 문자열을 컴퓨터로 재전송
    mySerial.println("Received message : " + String(buffer));
    // ‘OK’ 문자열이 수신될 때까지 대기
    if(String("OK").equals(buffer)) { // C언어의 strcmp와 비슷한 함수(비교)
      break; 
      }
    }
  }
  mySerial.println("You send me a brightness value."); // 밝기값 입력 대기
}

void setup()
{
  mySerial.begin(9600); // 시리얼 통신 초기화
  pinMode(ledPin, OUTPUT); // LED 핀을 출력으로 설정
  Establish_Connection(); // Serial Handshaking 설정
}
void loop()
{
  if (mySerial.available() > 0) { // 수신 문자열이 있는 경우
  int brightness = mySerial.parseInt(); // 첫 번째 유효한 정수 읽기
  brightness = constrain(brightness, 0, 255); // 0에서 255 사이 값으로 제한을 건다
  analogWrite(ledPin, brightness); // LED 밝기 조절
  // 현재 밝기값을 컴퓨터로 전송
  mySerial.println("Current brightness is " + String(brightness, DEC));
  }
}


